==> qt-creator-opensource-src-4.7.1.zip: qt-creator-opensource-src-4.7.1/src/tools/clangrefactoringbackend/source/sourcedependency.h <==
/****************************************************************************
**
** Copyright (C) 2018 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <filepathid.h>

#include <vector>

namespace ClangBackEnd {

class SourceDependency
{
public:
    SourceDependency(FilePathId filePathId,
                    FilePathId dependencyFilePathId)
        : filePathId(filePathId),
          dependencyFilePathId(dependencyFilePathId)
    {}

    friend
    bool operator==(SourceDependency first, SourceDependency second)
    {
        return first.filePathId == second.filePathId
            && first.dependencyFilePathId == second.dependencyFilePathId;
    }

public:
    FilePathId filePathId;
    FilePathId dependencyFilePathId;
};

using SourceDependencies = std::vector<SourceDependency>;
}

==> qt-creator-opensource-src-4.12.4.zip: qt-creator-opensource-src-4.12.4/src/tools/clangrefactoringbackend/source/sourcedependency.h <==
/****************************************************************************
**
** Copyright (C) 2018 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <filepathid.h>

#include <vector>

namespace ClangBackEnd {

class SourceDependency
{
public:
    SourceDependency(FilePathId filePathId, FilePathId dependencyFilePathId)
        : filePathId(filePathId)
        , dependencyFilePathId(dependencyFilePathId)
    {}

    friend bool operator==(SourceDependency first, SourceDependency second)
    {
        return first.filePathId == second.filePathId
               && first.dependencyFilePathId == second.dependencyFilePathId;
    }

    friend bool operator!=(SourceDependency first, SourceDependency second)
    {
        return !(first == second);
    }

    friend bool operator<(SourceDependency first, SourceDependency second)
    {
        return std::tie(first.filePathId, first.dependencyFilePathId)
               < std::tie(second.filePathId, second.dependencyFilePathId);
    }

public:
    FilePathId filePathId;
    FilePathId dependencyFilePathId;
};

using SourceDependencies = std::vector<SourceDependency>;
} // namespace ClangBackEnd
